@@ -1,5 +1,4 @@
-"""
-Entry-point module, in case you use `python -m duty`.
+"""Entry-point module, in case you use `python -m duty`.
 
 Why does this file exist, and why `__main__`? For more info, read:
 
@@ -9,7 +8,7 @@ Why does this file exist, and why `__main__`? For more info, read:
 
 import sys
 
-from duty.cli import main
+from duty._internal.cli import main
 
 if __name__ == "__main__":
     sys.exit(main(sys.argv[1:]))
